==> ruby-1.4.6.tgz: lib/ruby/1.4/alpha-freebsd4.2/rbconfig.rb <==

module Config

  VERSION == "1.4.6" or
    raise "ruby lib version (1.4.6) doesn't match executable version (#{VERSION})"

# This file was created by configrb when ruby was built. Any changes
# made to this file will be lost the next time ruby is built.
  CONFIG = {}
  CONFIG["srcdir"] = "/a/ports/lang/ruby14/work/ruby-1.4.6"
  CONFIG["prefix"] = "/usr/local"
  CONFIG["ruby_install_name"] = "ruby14"
  CONFIG["EXEEXT"] = ""
  CONFIG["SHELL"] = "/bin/sh"
  CONFIG["CFLAGS"] = "-O -pipe -fPIC"
  CONFIG["CPPFLAGS"] = ""
  CONFIG["CXXFLAGS"] = "-O -pipe"
  CONFIG["FFLAGS"] = ""
  CONFIG["LDFLAGS"] = "-rdynamic"
  CONFIG["LIBS"] = "-lcrypt -lm "
  CONFIG["exec_prefix"] = "#{CONFIG[\"prefix\"]}"
  CONFIG["bindir"] = "#{CONFIG[\"exec_prefix\"]}/bin"
  CONFIG["sbindir"] = "#{CONFIG[\"exec_prefix\"]}/sbin"
  CONFIG["libexecdir"] = "#{CONFIG[\"exec_prefix\"]}/libexec"
  CONFIG["datadir"] = "#{CONFIG[\"prefix\"]}/share"
  CONFIG["sysconfdir"] = "#{CONFIG[\"prefix\"]}/etc"
  CONFIG["sharedstatedir"] = "#{CONFIG[\"prefix\"]}/com"
  CONFIG["localstatedir"] = "#{CONFIG[\"prefix\"]}/var"
  CONFIG["libdir"] = "#{CONFIG[\"exec_prefix\"]}/lib"
  CONFIG["includedir"] = "#{CONFIG[\"prefix\"]}/include"
  CONFIG["oldincludedir"] = "/usr/include"
  CONFIG["infodir"] = "#{CONFIG[\"prefix\"]}/info"
  CONFIG["mandir"] = "#{CONFIG[\"prefix\"]}/man"
  CONFIG["MAJOR"] = "1"
  CONFIG["MINOR"] = "4"
  CONFIG["TEENY"] = "6"
  CONFIG["host"] = "alpha-unknown-freebsd4.2"
  CONFIG["host_alias"] = "alpha-freebsd4.2"
  CONFIG["host_cpu"] = "alpha"
  CONFIG["host_vendor"] = "unknown"
  CONFIG["host_os"] = "freebsd4.2"
  CONFIG["CC"] = "cc"
  CONFIG["CPP"] = "cc -E"
  CONFIG["YACC"] = "byacc"
  CONFIG["RANLIB"] = "ranlib"
  CONFIG["AR"] = "ar"
  CONFIG["LN_S"] = "ln -s"
  CONFIG["SET_MAKE"] = ""
  CONFIG["OBJEXT"] = "o"
  CONFIG["LIBOBJS"] = ""
  CONFIG["ALLOCA"] = ""
  CONFIG["DEFAULT_KCODE"] = ""
  CONFIG["XLDFLAGS"] = ""
  CONFIG["DLDFLAGS"] = "-Wl,-soname,$(.TARGET)"
  CONFIG["STATIC"] = ""
  CONFIG["CCDLFLAGS"] = "-fPIC"
  CONFIG["LDSHARED"] = "cc -shared"
  CONFIG["DLEXT"] = "so"
  CONFIG["STRIP"] = "strip"
  CONFIG["EXTSTATIC"] = ""
  CONFIG["setup"] = "Setup"
  CONFIG["LIBRUBY_LDSHARED"] = "cc -shared"
  CONFIG["LIBRUBY_DLDFLAGS"] = "-Wl,-soname,$(.TARGET)"
  CONFIG["RUBY_INSTALL_NAME"] = "ruby14"
  CONFIG["LIBRUBY_A"] = "lib$(RUBY_INSTALL_NAME).a"
  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_INSTALL_NAME).so.$(MAJOR)$(MINOR)"
  CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_INSTALL_NAME).so"
  CONFIG["LIBRUBY"] = "$(LIBRUBY_SO)"
  CONFIG["LIBRUBYARG"] = "-L. -l$(RUBY_INSTALL_NAME)"
  CONFIG["SOLIBS"] = ""
  CONFIG["arch"] = "alpha-freebsd4.2"
  CONFIG["sitedir"] = "/usr/local/lib/ruby/site_ruby"
  CONFIG["configure_args"] = "--enable-shared --program-suffix=14 --enable-ipv6 --prefix=/usr/local alpha-freebsd4.2"
  CONFIG["compile_dir"] = "/a/ports/lang/ruby14/work/ruby-1.4.6"
  CONFIG.each_value do |val|
    val.gsub!(/\$\(([^()]+)\)/) do |var|
      key = $1
      if CONFIG.key? key
        "#{CONFIG[\"#{key}\"]}"
      else
	var
      end
    end
  end
end

==> ruby-1.6.2.p2.tgz: lib/ruby/1.6/alpha-freebsd4.2/rbconfig.rb <==

module Config

  VERSION == "1.6.2" or
    raise "ruby lib version (1.6.2) doesn't match executable version (#{VERSION})"

# This file was created by configrb when ruby was built. Any changes
# made to this file will be lost the next time ruby is built.
  DESTDIR = '' if not defined? DESTDIR
  CONFIG = {}
  TOPDIR = File.dirname(__FILE__).sub!(%r'/lib/ruby/1\.6/alpha\-freebsd4\.2\Z', '')
  CONFIG["srcdir"] = "/a/ports/lang/ruby/work/ruby-1.6.2"
  CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
  CONFIG["ruby_install_name"] = "ruby"
  CONFIG["EXEEXT"] = ""
  CONFIG["SHELL"] = "/bin/sh"
  CONFIG["CFLAGS"] = "-O -pipe -fPIC"
  CONFIG["CPPFLAGS"] = ""
  CONFIG["CXXFLAGS"] = "-O -pipe"
  CONFIG["FFLAGS"] = ""
  CONFIG["LDFLAGS"] = "-rdynamic"
  CONFIG["LIBS"] = "-lcrypt -lm "
  CONFIG["exec_prefix"] = "#{CONFIG[\"prefix\"]}"
  CONFIG["bindir"] = "#{CONFIG[\"exec_prefix\"]}/bin"
  CONFIG["sbindir"] = "#{CONFIG[\"exec_prefix\"]}/sbin"
  CONFIG["libexecdir"] = "#{CONFIG[\"exec_prefix\"]}/libexec"
  CONFIG["datadir"] = "#{CONFIG[\"prefix\"]}/share"
  CONFIG["sysconfdir"] = "#{CONFIG[\"prefix\"]}/etc"
  CONFIG["sharedstatedir"] = "#{CONFIG[\"prefix\"]}/com"
  CONFIG["localstatedir"] = "#{CONFIG[\"prefix\"]}/var"
  CONFIG["libdir"] = "#{CONFIG[\"exec_prefix\"]}/lib"
  CONFIG["includedir"] = "#{CONFIG[\"prefix\"]}/include"
  CONFIG["oldincludedir"] = "/usr/include"
  CONFIG["infodir"] = "#{CONFIG[\"prefix\"]}/info"
  CONFIG["mandir"] = "#{CONFIG[\"prefix\"]}/man"
  CONFIG["MAJOR"] = "1"
  CONFIG["MINOR"] = "6"
  CONFIG["TEENY"] = "2"
  CONFIG["host"] = "alpha-unknown-freebsd4.2"
  CONFIG["host_alias"] = "alpha-freebsd4.2"
  CONFIG["host_cpu"] = "alpha"
  CONFIG["host_vendor"] = "unknown"
  CONFIG["host_os"] = "freebsd4.2"
  CONFIG["target"] = "alpha-unknown-freebsd4.2"
  CONFIG["target_alias"] = "alpha-freebsd4.2"
  CONFIG["target_cpu"] = "alpha"
  CONFIG["target_vendor"] = "unknown"
  CONFIG["target_os"] = "freebsd4.2"
  CONFIG["build"] = "alpha-unknown-freebsd4.2"
  CONFIG["build_alias"] = "alpha-freebsd4.2"
  CONFIG["build_cpu"] = "alpha"
  CONFIG["build_vendor"] = "unknown"
  CONFIG["build_os"] = "freebsd4.2"
  CONFIG["CC"] = "cc"
  CONFIG["CPP"] = "cc -E"
  CONFIG["YACC"] = "byacc"
  CONFIG["RANLIB"] = "ranlib"
  CONFIG["AR"] = "ar"
  CONFIG["NM"] = ""
  CONFIG["DLLWRAP"] = ""
  CONFIG["AS"] = ""
  CONFIG["DLLTOOL"] = ""
  CONFIG["WINDRES"] = ""
  CONFIG["LN_S"] = "ln -s"
  CONFIG["SET_MAKE"] = ""
  CONFIG["OBJEXT"] = "o"
  CONFIG["LIBOBJS"] = ""
  CONFIG["ALLOCA"] = ""
  CONFIG["XLDFLAGS"] = ""
  CONFIG["DLDFLAGS"] = "-Wl,-soname,$(.TARGET)"
  CONFIG["STATIC"] = ""
  CONFIG["CCDLFLAGS"] = "-fPIC"
  CONFIG["LDSHARED"] = "cc -shared"
  CONFIG["DLEXT"] = "so"
  CONFIG["DLEXT2"] = ""
  CONFIG["STRIP"] = "strip"
  CONFIG["EXTSTATIC"] = ""
  CONFIG["setup"] = "Setup"
  CONFIG["MINIRUBY"] = "./miniruby$(EXEEXT)"
  CONFIG["PREP"] = ""
  CONFIG["LIBRUBY_LDSHARED"] = "cc -shared"
  CONFIG["LIBRUBY_DLDFLAGS"] = "-Wl,-soname,$(.TARGET)"
  CONFIG["RUBY_INSTALL_NAME"] = "ruby"
  CONFIG["RUBY_SO_NAME"] = ""
  CONFIG["LIBRUBY_A"] = "lib$(RUBY_INSTALL_NAME).a"
  CONFIG["LIBRUBY_SO"] = "lib$(RUBY_INSTALL_NAME).so.$(MAJOR)$(MINOR)"
  CONFIG["LIBRUBY_ALIASES"] = "lib$(RUBY_INSTALL_NAME).so"
  CONFIG["LIBRUBY"] = "$(LIBRUBY_SO)"
  CONFIG["LIBRUBYARG"] = "-L. -l$(RUBY_INSTALL_NAME)"
  CONFIG["SOLIBS"] = ""
  CONFIG["DLDLIBS"] = "-lc"
  CONFIG["ENABLE_SHARED"] = "yes"
  CONFIG["arch"] = "alpha-freebsd4.2"
  CONFIG["sitedir"] = "#{CONFIG[\"prefix\"]}/lib/ruby/site_ruby"
  CONFIG["configure_args"] = "--enable-shared --enable-ipv6 --prefix=/usr/local alpha-freebsd4.2"
  CONFIG["compile_dir"] = "/a/ports/lang/ruby/work/ruby-1.6.2"
  MAKEFILE_CONFIG = {}
  CONFIG.each{|k,v| MAKEFILE_CONFIG[k] = v.dup}
  def Config::expand(val)
    val.gsub!(/\$\(([^()]+)\)/) do |var|
      key = $1
      if CONFIG.key? key
        "#{Config::expand(CONFIG[\"#{key}\"])}"
      else
	var
      end
    end
    val
  end
  CONFIG.each_value do |val|
    Config::expand(val)
  end
end
